@@ -176,7 +176,7 @@ class FuraServerImpl(FuraServerInterface):
         if not role:
             raise Exception('Auth role is not set!')
 
-        return role
+        return self._dao.role_get(self._site_id(), role)
 
 
     def get_fura_token(self):
