@@ -679,7 +679,7 @@ Please contact your system administrator.')
         ecode        = await self._dao.otp_ok(otp_str, 'confirm_contact', usr_rec.site_id, usr_rec.id, otp_meta)
 
         if ecode != ErrCode.NoError:
-            raise xMettle('Invalid OTP', errCode=ecode)
+            raise xMettle('Invalid OTP', err_code=ecode)
 
         orig         = copy.copy(usr_rec)
         contact_addr = otp_meta.get('addr')
